var EventEmitter = require('sk/core/events').EventEmitter,
exec = require('child_process').exec,
Configuration = require('./models/configuration'),
supervisord = require('supervisord'),
nodefs = require('node-fs');


var Beet = EventEmitter.extend({

    /**
     */

    'override __construct': function()
    {
        this._super();

        this.dirs = {
            conf: '/etc/beet/conf',
            logs: '/var/log/beet'  
        };


        //make all the directories for the app 
        for(var type in this.dirs) nodefs.mkdirSync(this.dirs[type], 0755, true);


        //the root supervisord configuration file
        this.root = this.configuration('/etc/supervisord.conf');

        //root scripts away from the default config
        this.scripts = this.configuration(this.dirs.conf + '/scripts.conf');

        //for the RPC interface - required
        var inet_http_server = this.root.get('inet_http_server');

        //connection to supervisord
        this.client = supervisord.connect({
            host: 'localhost',
            user: inet_http_server.username,
            pass: inet_http_server.password,
            port: Number(inet_http_server.port.split(':').pop())
        });


        //we don't want to touch the root config too much - include the beet config directory to scan
        this.root.include(this.dirs.conf + '/*.conf');
    },
    
    /**
     * returns a configuration model
     */


    'configuration': function(configPath)
    {
        return new Configuration(this, configPath);
    },

    /**
     */

    'processes': function(callback)
    {
        this.client.getAllProcessInfo(callback);
    },

    /**
     * updates supervisor. Have to resort to exec since there's no RPC interface for updating supervisord
     */

    'update': function(callback)
    {
        console.log('reloading beet config');

        exec('sudo supervisorctl update', callback || function(){});
    }
    
});

module.exports = new Beet();